@@ -12,15 +12,6 @@ namespace SebastianBergmann\PHPCPD\Log;
 
 use SebastianBergmann\PHPCPD\CodeCloneMap;
 
-/**
- * Base class for XML loggers.
- *
- * @author    Sebastian Bergmann <sebastian@phpunit.de>
- * @copyright Sebastian Bergmann <sebastian@phpunit.de>
- * @license   http://www.opensource.org/licenses/BSD-3-Clause  The BSD 3-Clause License
- * @link      http://github.com/sebastianbergmann/phpcpd/tree
- * @since     Class available since Release 1.0.0
- */
 abstract class AbstractXmlLogger
 {
     protected $document;
@@ -32,7 +23,7 @@ abstract class AbstractXmlLogger
      */
     public function __construct($filename)
     {
-        $this->document = new \DOMDocument('1.0', 'UTF-8');
+        $this->document               = new \DOMDocument('1.0', 'UTF-8');
         $this->document->formatOutput = true;
 
         $this->filename = $filename;
@@ -43,22 +34,23 @@ abstract class AbstractXmlLogger
      */
     protected function flush()
     {
-        file_put_contents($this->filename, $this->document->saveXML());
+        \file_put_contents($this->filename, $this->document->saveXML());
     }
 
     /**
      * Converts a string to UTF-8 encoding.
      *
-     * @param  string $string
+     * @param string $string
+     *
      * @return string
      */
     protected function convertToUtf8($string)
     {
         if (!$this->isUtf8($string)) {
-            if (function_exists('mb_convert_encoding')) {
-                $string = mb_convert_encoding($string, 'UTF-8');
+            if (\function_exists('mb_convert_encoding')) {
+                $string = \mb_convert_encoding($string, 'UTF-8');
             } else {
-                $string = utf8_encode($string);
+                $string = \utf8_encode($string);
             }
         }
 
@@ -68,28 +60,29 @@ abstract class AbstractXmlLogger
     /**
      * Checks a string for UTF-8 encoding.
      *
-     * @param  string $string
-     * @return boolean
+     * @param string $string
+     *
+     * @return bool
      */
     protected function isUtf8($string)
     {
-        $length = strlen($string);
+        $length = \strlen($string);
 
         for ($i = 0; $i < $length; $i++) {
-            if (ord($string[$i]) < 0x80) {
+            if (\ord($string[$i]) < 0x80) {
                 $n = 0;
-            } elseif ((ord($string[$i]) & 0xE0) == 0xC0) {
+            } elseif ((\ord($string[$i]) & 0xE0) == 0xC0) {
                 $n = 1;
-            } elseif ((ord($string[$i]) & 0xF0) == 0xE0) {
+            } elseif ((\ord($string[$i]) & 0xF0) == 0xE0) {
                 $n = 2;
-            } elseif ((ord($string[$i]) & 0xF0) == 0xF0) {
+            } elseif ((\ord($string[$i]) & 0xF0) == 0xF0) {
                 $n = 3;
             } else {
                 return false;
             }
 
             for ($j = 0; $j < $n; $j++) {
-                if ((++$i == $length) || ((ord($string[$i]) & 0xC0) != 0x80)) {
+                if ((++$i == $length) || ((\ord($string[$i]) & 0xC0) != 0x80)) {
                     return false;
                 }
             }
@@ -98,6 +91,31 @@ abstract class AbstractXmlLogger
         return true;
     }
 
+    /**
+     * Escapes a string for inclusion inside an XML tag.
+     *
+     * Converts the string to UTF-8, substitutes the unicode replacement
+     * character for every character disallowed in XML, and escapes
+     * special characters.
+     *
+     * @param string $string
+     *
+     * @return string
+     */
+    protected function escapeForXml($string)
+    {
+        $string = $this->convertToUtf8($string);
+
+        // Substitute the unicode replacement character for disallowed chars
+        $string = \preg_replace(
+            '/[^\x09\x0A\x0D\x{0020}-\x{D7FF}\x{E000}-\x{FFFD}]/u',
+            "\xEF\xBF\xBD",
+            $string
+        );
+
+        return \htmlspecialchars($string, ENT_COMPAT, 'UTF-8');
+    }
+
     /**
      * Processes a list of clones.
      *
